import os
import voiceprint_recognition.Tools.SR_Model as VI_model
global MODEL, MODEL_PATH
directory_to_project = dir_path = os.path.dirname(os.path.realpath(__file__))
TEST_FILE = f"{dir_path}/test/test_output.wav"


def setModelPath(modelPath):
    global MODEL_PATH
    # MODEL_PATH = modelPath
    modelpath = open(f"{dir_path}/txtPath/ModelPath.txt", "w")
    modelpath.write(f"{modelPath}/VImodel")
    modelpath.close()
    wordPath = open(f"{dir_path}/txtPath/wordPath.txt", "w")
    wordPath.write(f"{modelPath}/VIwords")
    wordPath.close()


def getModelPath():
    modalPath = open(f"{dir_path}/txtPath/ModelPath.txt", "r")
    readModalPath = modalPath.read()
    modalPath.close()
    return readModalPath


def getAccuracyFilePath():
    """
    Returns:
        the accuracy file path of current recorded with microphone
    """
    return f"{getModelPath()}//m_accuracy.txt"


def getWordPath():
    wordPath = open(f"{dir_path}/txtPath/wordPath.txt", "r")
    word = wordPath.read()
    wordPath.close()
    return word


def getPath():
    dir_path = os.path.dirname(os.path.realpath(__file__))
    return dir_path


def getTestWaveFile():
    """
    returns the predicted recorded file path.
    Returns:
        the predicted recorded file path.
    """
    return f"{getPath()}\\test\\test_output.wav"


def loadModel():
    """
    returns the saved model in the container
    Returns:
        the saved model in the container
    """
    return SR_Model.loadModel()


def userNames():
    """
    returns the name of users in a list formate
    Returns:
        the name of users in a list formate
    """
    return os.listdir(f"{getWordPath()}\\sentence\\")

def userCount():
    """
    returns the no of users that has been stored
    Returns:
        the no of users that has been stored
    """
    return len(os.listdir(f"{getWordPath()}\\sentence\\"))




import os
import shutil
from voiceprint_recognition.Tools import Data
from voiceprint_recognition.Tools import SR_Model
from voiceprint_recognition.Tools import Predictor
import voiceprint_recognition.Container as Container
import time
import warnings
import tensorflow as tf
import logging
global saveModelPath, loadModelPath, accuracyPath
directory_to_project = dir_path = os.path.dirname(os.path.realpath(__file__))

def start(getDIR):
    """Used to create a personal space for your file
    When we have to work on two different schemas of work..
    there is a confusion in them for the Compiler , Engine.Start() plays a vital role in sorting on the different
    projects by preloading in them when needed automatically.

    Short : Engine is used for taking up the directive to work with different projects at the same time
    when working we must pass the directive as parameter in the engine to take up the path to work in it

    """
    tf.get_logger().setLevel(logging.ERROR)
    warnings.filterwarnings("ignore")
    Container.setModelPath(getDIR)
    if not os.path.exists(Container.getModelPath()):
        # os.makedirs("model")
        source_dir = directory_to_project+"/model"
        destination_dir = Container.getModelPath()
        Container.MODEL_PATH = Container.getModelPath()
        shutil.copytree(source_dir, destination_dir)
    if not os.path.exists(Container.getWordPath()):
        source_dir = dir_path+"/words"
        destination_dir = Container.getWordPath()
        shutil.copytree(source_dir, destination_dir)
    Data.names = os.listdir(f"{Container.getWordPath()}\\sentence")
    try:
        SR_Model.DIR_MODEL = f"{Container.getModelPath()}\\saved_model"
        SR_Model.ACCURACY_TEXT_FILE = f"{Container.getModelPath()}\\saved_model\\m_accuracy.txt"
    except NameError:
        print("saveModelPath is not defined\nPlease set Model Name\nHelp --> You have to ")
    # Container.MODEL = SR_Model.loadModel()
    Predictor.WAVE_OUTPUT_FILENAME = f"{dir_path}/test/test_output.wav"  # testing file
    print("Engine Started...")
    time.sleep(2)

# start()